@@ -1,17 +1,19 @@
 package Log::Any::Adapter::Dispatch;
+# ABSTRACT: Adapter to use Log::Dispatch with Log::Any
+our $VERSION = '0.07';
+
 use Log::Any::Adapter::Util qw(make_method);
 use Log::Dispatch;
 use strict;
 use warnings;
 use base qw(Log::Any::Adapter::Base);
 
-our $VERSION = '0.06';
-
 sub init {
     my $self = shift;
 
     # If a dispatcher was not explicitly passed in, create a new one with the passed arguments.
     #
+    $_[-2] eq "category" and splice @_, -2, 2;
     $self->{dispatcher} ||= Log::Dispatch->new(@_);
 }
 
@@ -40,9 +42,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Log::Any::Adapter::Dispatch
+Log::Any::Adapter::Dispatch - Adapter to use Log::Dispatch with Log::Any
+
+=head1 VERSION
+
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -67,15 +75,25 @@ I<dispatcher> parameter.
 L<Log::Any::Adapter|Log::Any::Adapter>, L<Log::Any|Log::Any>,
 L<Log::Dispatch|Log::Dispatch>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Jonathan Swartz
+=over 4
 
-=head1 COPYRIGHT & LICENSE
+=item *
 
-Copyright (C) 2007 Jonathan Swartz, all rights reserved.
+Jonathan Swartz <swartz@pobox.com>
 
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+=item *
+
+Doug Bell <preaction@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Jonathan Swartz and Doug Bell.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
